Learn R Programming

fmx (version 0.1.2)

[,fmx,ANY,ANY,ANY-method: Subset of Components in fmx Object

Description

Taking subset of components in fmx object

Usage

# S4 method for fmx,ANY,ANY,ANY
[(x, i)

Value

An fmx object consisting of a subset of components. information about the observations (e.g. slots @data and @data.name), will be lost.

Arguments

x

fmx object

i

integer or logical vector, the row indices of components to be chosen, see [

Details

Using definitions as S3 method dispatch `[.fmx` won't work for fmx objects.

Examples

Run this code

(d = fmx('norm', mean = c(1, 4, 7), w = c(1, 1, 1)))
d[1:2]

Run the code above in your browser using DataLab