powered by
Taking subset of components in fmx object
# S4 method for fmx,ANY,ANY,ANY [(x, i)
An fmx object consisting of a subset of components. information about the observations (e.g. slots @data and @data.name), will be lost.
@data
@data.name
fmx object
integer or logical vector, the row indices of components to be chosen, see [
Using definitions as S3 method dispatch `[.fmx` won't work for fmx objects.
`[.fmx`
(d = fmx('norm', mean = c(1, 4, 7), w = c(1, 1, 1))) d[1:2]
Run the code above in your browser using DataLab