| as.fmx | R Documentation |
Turn various objects created in other R packages to fmx class.
as.fmx(x, ...)
x |
an R object |
... |
additional parameters, see **Arguments** in individual S3 dispatches |
Various mixture distribution estimates obtained from other R packages are converted to fmx class, so that we could take advantage of all methods defined for fmx objects.
S3 generic function [as.fmx()] returns an fmx object.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.