confint.fmx: Confidence Interval of fmx Object

View source: R/S3.R

confint.fmxR Documentation

Confidence Interval of fmx Object

Description

...

Usage

## S3 method for class 'fmx'
confint(object, ..., level = 0.95)

Arguments

object

fmx object

...

place holder for S3 naming convention

level

confidence level, default 95\%.

Details

The function [confint.fmx()] returns the Wald-type confidence intervals based on the user-friendly parameters (‘parm = ’user''), or the internal/unconstrained parameters (‘parm = ’internal''). When the distribution has constraints on one or more parameters, function [confint.fmx()] does not return the confident intervals of for the constrained parameters.

Value

The function [confint.fmx()] returns a matrix


fmx documentation built on July 17, 2026, 1:07 a.m.