fmx: Create fmx Object for Finite Mixture Distribution

View source: R/0S4.R

fmxR Documentation

Create fmx Object for Finite Mixture Distribution

Description

To create fmx object for finite mixture distribution.

Usage

fmx(distname, w = 1, ...)

Arguments

distname

character scalar

w

(optional) numeric vector. Does not need to sum up to 1; 'w/sum(w)' will be used internally.

...

mixture distribution parameters. See function dGH for the names and default values of Tukey g-&-h distribution parameters, or dnorm for the names and default values of normal distribution parameters.

Value

The function [fmx()] returns an fmx object.


fmx documentation built on July 17, 2026, 1:07 a.m.