fmx_constraint: Parameter Constraint(s) of Mixture Distribution

View source: R/fmx_constraint.R

fmx_constraintR Documentation

Parameter Constraint(s) of Mixture Distribution

Description

Determine the parameter constraint(s) of a finite mixture distribution fmx, either by the value of parameters of such mixture distribution, or by a user-specified string.

Usage

fmx_constraint(
  dist,
  distname = dist@distname,
  K = dim(dist@pars)[1L],
  pars = dist@pars
)

Arguments

dist

(optional) fmx object

distname

character scalar, name of distribution (see fmx), default value determined by 'dist'

K

integer scalar, number of components, default value determined by 'dist'

pars

double matrix, distribution parameters of a finite mixture distribution (see fmx), default value determined by 'dist'

Value

The function [fmx_constraint()] returns the indices of internal parameters (only applicable to Tukey g-&-h mixture distribution, yet) to be constrained, based on the input fmx object 'dist'.


fmx documentation built on July 17, 2026, 1:07 a.m.