moment_fmx: Moment of Each Component in an fmx Object

View source: R/moment.R

moment_fmxR Documentation

Moment of Each Component in an fmx Object

Description

To find moments of each component in an fmx object.

Usage

moment_fmx(object)

Arguments

object

an fmx object

Details

The function [moment_fmx()] calculates the moments and distribution characteristics of each mixture component of an S4 fmx object.

Value

The function [moment_fmx()] returns an object of the S4 moment-class.


fmx documentation built on July 17, 2026, 1:07 a.m.