View source: R/fmx_constraint.R
| fmx_constraint | R Documentation |
Determine the parameter constraint(s) of a finite mixture distribution fmx, either by the value of parameters of such mixture distribution, or by a user-specified string.
fmx_constraint(
dist,
distname = dist@distname,
K = dim(dist@pars)[1L],
pars = dist@pars
)
dist |
(optional) fmx object |
distname |
character scalar, name of distribution (see fmx), default value determined by 'dist' |
K |
integer scalar, number of components, default value determined by 'dist' |
pars |
double matrix, distribution parameters of a finite mixture distribution (see fmx), default value determined by 'dist' |
The function [fmx_constraint()] returns the indices of internal parameters
(only applicable to Tukey g-&-h mixture distribution, yet) to be constrained,
based on the input fmx object 'dist'.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.