| moment_fmx | R Documentation |
To find moments of each component in an fmx object.
moment_fmx(object)
object |
an fmx object |
The function [moment_fmx()] calculates the moments and distribution characteristics of each mixture component of an S4 fmx object.
The function [moment_fmx()] returns an object of the S4 moment-class.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.