Learn R Programming

fmx (version 0.1.2)

moment_fmx: Moment of Each Component in an fmx Object

Description

To find moments of each component in an fmx object.

Usage

moment_fmx(object)

Value

Function moment_fmx returns a moment object.

Arguments

object

an fmx object

Details

Function moment_fmx calculates the moments and distribution characteristics of each mixture component of an S4 fmx object.

Examples

Run this code
(d2 = fmx('GH', A = c(1,6), B = 2, g = c(0,.3), h = c(.2,0), w = c(1,2)))
moment_fmx(d2)

Run the code above in your browser using DataLab